summaryrefslogtreecommitdiffstats
path: root/tests/functional/glusterd/test_volume_status.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/functional/glusterd/test_volume_status.py')
-rw-r--r--tests/functional/glusterd/test_volume_status.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/functional/glusterd/test_volume_status.py b/tests/functional/glusterd/test_volume_status.py
index ff5d5752f..109586f35 100644
--- a/tests/functional/glusterd/test_volume_status.py
+++ b/tests/functional/glusterd/test_volume_status.py
@@ -110,17 +110,17 @@ class VolumeStatusWhenIOInProgress(GlusterBaseClass):
command on all clusters randomly.
"gluster volume status volname inode" command should not get
hang while IOs in progress.
Then check that IOs completed successfullly or not on mount point.
Check that files in mount point listing properly or not.
'''
# Mounting a volume
ret = self.mount_volume(self.mounts)
self.assertTrue(ret, "Volume mount failed for %s" % self.volname)
- g.log.info("Volume mounted sucessfully : %s", self.volname)
+ g.log.info("Volume mounted successfully : %s", self.volname)
- # After Mounting immediately writting IO's are failing some times,
- # thats why keeping sleep for 10 secs
+ # After Mounting immediately writing IO's are failing some times,
+ # that's why keeping sleep for 10 secs
sleep(10)
# run IOs
@@ -110,17 +110,17 @@ class VolumeStatusWhenIOInProgress(GlusterBaseClass):
"gluster volume status volname inode" command should not get
hang while IOs in progress.
- Then check that IOs completed successfullly or not on mount point.
+ Then check that IOs completed successfully or not on mount point.
Check that files in mount point listing properly or not.
'''